@@ -4,7 +4,9 @@ use strict;
 
 use Mojo::Base 'Test::Mojo';
 use Mojo::Util 'squish';
-our $VERSION = '0.09';
+
+our $VERSION = '0.0901'; # VERSION
+# ABSTRACT: Trim strings for Test::Mojo
 
 sub trimmed_content_is {
     my $self = shift;
@@ -35,18 +37,29 @@ sub trimmed_content_is {
 }
 
 1;
+
 __END__
 
+=pod
+
 =encoding utf-8
 
 =head1 NAME
 
-Test::Mojo::Trim - Test::Mojo expanded
+Test::Mojo::Trim - Trim strings for Test::Mojo
 
-=for html <p><a style="float: left;" href="https://travis-ci.org/Csson/p5-test-mojo-trim"><img src="https://travis-ci.org/Csson/p5-test-mojo-trim.svg?branch=master">&nbsp;</a>
+=head1 VERSION
+
+Version 0.0901, released 2015-02-06.
 
 =head1 SYNOPSIS
 
+=head1 DESCRIPTION
+
+Test::Mojo::Trim is an extension to Test::Mojo, that adds an additional string comparison function.
+
+=for html <p><a style="float: left;" href="https://travis-ci.org/Csson/p5-test-mojo-trim"><img src="https://travis-ci.org/Csson/p5-test-mojo-trim.svg?branch=master">&nbsp;</a>
+
     use Mojo::Base -strict;
     use Mojolicious::Lite;
     use Test::More;
@@ -69,10 +82,6 @@ Test::Mojo::Trim - Test::Mojo expanded
         <p>A paragraph.</p>
     </div>
 
-=head1 DESCRIPTION
-
-Test::Mojo::Trim is an extension to Test::Mojo, that adds an additional string comparison function.
-
 =head1 METHODS
 
 L<Test::Mojo::Trim> inherits all methods from L<Test::Mojo> and implements the following new one.
@@ -84,19 +93,6 @@ L<Test::Mojo::Trim> inherits all methods from L<Test::Mojo> and implements the f
 Removes all whitespace between tags from the two strings that are compared.
 That is, if a E<gt> and E<lt> is separated only by whitespace, that whitespace is removed.
 
-=head1 AUTHOR
-
-Erik Carlsson E<lt>info@code301.comE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2014- Erik Carlsson
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
 =over 4
@@ -111,4 +107,23 @@ L<Test::Mojo::Most>
 
 =back
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-test-mojo-trim>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Test-Mojo-Trim>
+
+=head1 AUTHOR
+
+Erik Carlsson <info@code301.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by Erik Carlsson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
